---
author: François Pelletier
title: Notes de cours - examen final
fig_caption: yes
highlight: pygments
number_sections: yes
toc: yes
toc_depth: 3
geometry: "left=2cm,right=2cm,top=2cm,bottom=2cm"
fontsize: 12pt
---

# Extraction d'information

Objectif: obtenir de l'information utile et la structurer.

Usages:

- Compréhension de textes
- Systèmes questions-réponses
- Traductions automatiques

Approches:

- À base de règles
- Par apprentissage

## Types d'information:

- Quasi structurée: texte préformaté, par exemple un bulletin météo
- Semi structurée: texte en points de forme, par exemple une annonce classée
- Non structurée: texte libre, par exemple un article de nouvelles

## Types d'extraction

- Reconnaissance d'entitées nommées
- Détection et classification de relations
- Détection et classification d'évènements

## Reconnaissance d'entitées nommées

**Entité nommée**: Se désigne par un nom propre, une quantité, une date, une marque temportelle ou un montant d'argent. Peuvent être spécifiques au domaine d'application

Objectif: Trouver les entitées nommées et les classer selon leur type. 

Usages:

- Indexation
- Identification de relations
- Résolution de requêtes
- Lien avec une base de connaissances

Exemples de types d'entités nommées:

- Personne
- Marques de commerce
- Lieu
- Organisation
- Géopolitique
- Argent
- Temps

Enjeux: ambiguité du type des entités. Peuvent appartenir à plusieurs catégories

### Approches de NER

#### Apprentissage automatique:

Encodage IOB mot par mot:

- **B**eginning (premier jeton de l'entité)
- **I**nside (autres jetons de l'entité)
- **O**utside (ne fait pas partie d'une entité nommée)

Chaque étiquette a une position et un type, pour un total de $2n+1$ étiquettes possibles.

Étiquetage séquentiel:

- MEMM/CRF (généralisation de Viterbi)
- bi-LSTM (réseau de neurones récurrent et bidirectionnel)
- HMM (Modèle de Markov caché)
- SVM (Modèle discriminant)

Extraction des attributs des mots:

- identité, plongement, POS du mot et des voisins
- Étiquette syntaxique du mot, du groupe de mot et des mots voisins
- Mot présent dans un index géographique
- Contient un préfixe ou un suffixe
- Tout en majuscules
- Forme du mot et des voisins
- Forme du mot court et des voisins
- Présente de trait ou de tiret

Portée d'un classificateur MEMM:

![Diagramme MEMM pour NER](memm-ner.png)

#### Base de règles

Caractéristiques:

- Largement utilisé en pratique
- Fort niveau de précision

Composantes:

- Listes d'entités
- Patrons ou expressions régulière pour reconnaitre des entités potentielles
- Patrons pour reconnaitre les environnements où des entités peuvent se trouver

Approche hybride:

1. Identifier les attributs:
    - Règles pour repérer les entités non-ambigues
    - Comparer des sous-chaines avec des entités connues
    - Listes de noms d'entités spécifiques
2. Classificateur de séquence

## Détection et classification de relations

Objectif: capturer les relations sémantiques du domaine d'application, populer une base de données

Formes des relations:

ENTITÉ - RELATION - ENTITÉ

Types de relations:

- PERSON-SOCIAL
    - Family
    - Business
    - Lasting personal
- PHYSICAL
    - Near
    - Located
- GENERAL AFFILIATION
    - Citizen
    - Resident
    - Ethnicity
    - Religion
    - Org-Location-Origin
- PART-WHOLE
    - Subsidiary
    - Geographical
- ORG AFFILIATION
    - Founder
    - Ownership
    - Membership
    - Sports affiliation
    - Employment
    - Student-Alumni
    - Investor
- ARTIFACT
    - User
    - Owner
    - Inventor
    - Manufacturer

### Exemple

| Domain | D = {a, b, c, d, e, f , g, h, i} |
|----------------------------------------------------------|--------------------------------------------|
| United, UAL, American Airlines, AMR | a, b, c, d |
| Tim Wagner | e |
| Chicago, Dallas, Denver, and San Francisco | f , g, h, i |


| Classes |  |
|----------------------------------------------------------|--------------------------------------------|
| United, UAL, American, and AMR are organizations | Org = {a, b, c, d} |
| Tim Wagner is a person | Pers = {e} |
| Chicago, Dallas, Denver, and San Francisco are places  | Loc = { f , g, h, i} |


| Relations |  |
|----------------------------------------------------------|--------------------------------------------|
| United is a unit of UAL | PartOf = {ha, bi, hc, di} |
| American is a unit of AMR |  |
| Tim Wagner works for American Airlines | OrgAff = {hc, ei} |
| United serves Chicago, Dallas, Denver, and San Francisco | Serves = {ha, f i, ha, gi, ha, hi, ha, ii} |

### Ressources

- Wikipedia
    - Infobox
- DBPedia
    - Représentation structurée de données provenant de Wikipedia
- Freebase
    - Personnes, lieux et objets
- Wordnet
    - Différentes relations sémantiques

### Approches possibles

- Règles écrites à la main
    - Forte précision
    - Faible rappel
    - Utiles pour un domaine spécifique, demande du temps pour la création des règles
- Apprentissage supervisé
    - Corpus d'entraînement étiqueté avec des entités et des relations
    - Classificateur pour chaque paire d'entités: 
        - Vérifier si reliées (modèle 1, exemples positifs et négatifs), 
        - Puis classifier la relation (modèle 2)
        - Régression logistique, Naïve Bayes, SVM
    - Attributs:
        - Prémisse (headword)
        - Mots précédant M1
        - Mots suivant M2
        - Mots entre M1 et M2
        - Type d'entité de M1
        - Type d'entité de M2
        - Concaténation des types
        - Analyse syntaxique des constituants
        - Analyse par morceaux (chunk) des constituants
        - Analyse des dépendances syntaxiques
- Apprentissage semi-supervisé
    - Classifier une relation sans corpus étiqueté
    - Bootstrapping (répéter plusieurs fois):
        - Quelques exemples
        - Extraire les paires d'entités de ces exemples
        - On les recherche dams un corpus ou sur le web
        - On apprend des patrons qui généralisent le contexte
        - On recherche ces patrons et on conserve ceux qui donnent plusieurs résultats
    - Semantic drift
        - Exemples erronés
        - Niveau de confiance:

        $$
        Conf(p) = \frac{hits_p}{finds_p} log(finds_p)
        $$

        - Niveau de confiance d'un exemple: 

        $$
        Conf(t) = 1-\prod_{p \in P}(1-Conf(p))
        $$

- Supervision distante
    - Utiliser une ressource avec un grand nombre d'exemples de qualité (DBPedia, Freebase, WordNet)
    - Trouver des phrases avec les entités de cette ressource
    - Extraire des exemples d'entraînement
    - Classificateur supervisé (avec les mêmes types d'attributs que l'approche supervisée)
    - Exemples négatifs: paires d'entités tirés au hasard qui n'apparaissent pas dans les relations
    - Avantages: mêmes que ceux des approches précédentes
    - Désavantage: Peu de relations pour de nouveaux domaines
- Apprentissage non supervisé
    - Patrons syntaxiques pour les relations:
    ```
    V | VP | VW*P
    V = verb particle? adv?
    W = (noun|adj|adv|pron|det)
    P = (prep|particle|inf. marker)
    ```
    - Segmenter les textes en phrases
    - Pour chaque phrase:
        - Faire un POS tagging et une analyse syntaxique
        - Trouver la plus longue séquence qui satisfait un patron à partir d'un verbe
        - Trouver les groupes nominaux à gauche et à droite
        - Déterminer un niveau de confiance en fonction de la fréquence des relations
    - Avantage: pas besoin de connaître les relations
    - Désavantage: On doit les convertir en relations sémantiques pour les stocker. Les relations sont basées sur des verbes, on va manquer les autres types de relations.

## Autres extractions

### Extraction d'expressions temporelles

- Similaire à l'extraction d'entitées nommées
- Doivent être normalisées. Peuvent être absolues, relatives ou sous la forme de durées.

### Détection et classification d'évènements

- Repérage des verbes d'actions, d'état ou de communication
- Classificateurs de séquences
- Tri chronologique des évènements, en utilisant aussi l'extraction d'expressions temporelles

# Systèmes questions-réponses

Types de questions:

- Factuelles (Qui, où) ?
- Complexes (Que pense, Comment) ?

![Système QA factuel](systeme-qa-factuel.png)

## Approche avec un corpus de texte

- Réponses dans des documents
- Recherche d'information (moteur de recherche et indexation)

### Traitement des questions

- Détection du type de réponse
- Formulation de requête pour le moteur de recherche d'information
- Information à extraire de la question:
    - Type de réponse
    - Focus
    - Type de question
    - Mots-clés pour la requête

### Extraction des termes de requête

- Termes de requête: pour repérer des passages. 
Exclure:
    - le mot-question, 
    - les mots-outils et 
    - les verbes fréquents
- Taille du corpus: une seule réponse, formulation différente
- Expansion de requête: 
    - variantes morphologiques (mots de la même famille)
    - synonymes (provenant d'un thesaurus)
- Reformulation:
    - Forme affirmative, avec règles de réécriture (phrase ou le mot manquant est la réponse)
    - Ex: 
        ```
        wh-word did A verb B -> A verb +ed B
        Where is A -> A is located in
        ```
### Détection du type d'entité de la réponse

- Permet de limiter les passages pertinents et se concentrer sur les bonnes phrases.
- **Limitations**: les types d'entités détectés par les logiciels NER sont limités
- Taxonomie de réponse à deux niveaux: Li&Roth
    - 6 grandes classes
    - 50 sous-classes

Deux approches:

- Règles manuelles (expressions régulières)
- Classification automatique:
    - Annotation des données d'entraînement
    - Classification avec ces attributs
        - Mots de la question
        - POS
        - Entités nommées
        - Mot principal (headword), du premier groupe nominal après le mot question

### Traitement de passages

- Résultat de la recherche: liste de documents priorisés selon leur similarité
- Problèmes:
    - Les documents ne sont pas les meilleures unités
    - Les documents en haut de la liste ne contiennent pas nécessairement la réponse
- Solution:
    - Découper les extraits des documents (segmantation)
        - Section, paragraphe, phrase
        - Fenêtre de mots
    - Filtrer les extraits qui ne semblent pas contenir de réponse
    - Réordonner ces extraits (avec des attributs)
        - \# d'entités nommées du bon type
        - \# de mots clés de la requête
        - Plus longue séquence de mots de la question
        - Rang du document d'où le passage provient
        - Proximité des mots-clés de la requête
        - Nombre de N-grammes en commun
    - Sur le web, utiliser les "snippets"

### Extraction de réponses

- Span labeling: identifier la portion du texte qui constitue la réponse
    - Approche: NER, retourner la chaîne du bon type
    - Si la réponse n'est pas une entité nommée, on utilise des règles. Ces règles peuvent être apprises (comme pour l'extraction de relations, par exemple)
- Si plusieurs réponses: on propose les différentes réponses ou on utilise un classificateur
    - Type de la réponse
    - Correspondance à un patron
    - Distance du mot-clé
    - Mot observé pour la première fois
    - Apposition (nombre de mots entre le mot-question et la réponse, avec un maximum de 3 mots et une virgule)
    - Position des ponctuations
    - Séquence de mots de la question
- Mean reciprocal rank

$$
MRR = \frac{1}{N}\sum_{i=1}^N \frac{1}{rank_i} 
$$

## Approche avec des données structurées

- Base de connaissances (entités et relations, dbPedia, Freebase, WordNet). Extraction d'information
- Ex: Siri, Wolfram Alpha

# Modèles statistiques de traduction automatique



